@@ -9,7 +9,6 @@
 import findpeaks.utils.compute as compute
 from findpeaks.utils.smoothline import smooth_line1d
 from peakdetect import peakdetect
-import cv2  # Only for 2D images required
 import matplotlib.pyplot as plt
 from tqdm import tqdm
 import pandas as pd
@@ -191,6 +190,13 @@ class findpeaks():
     # Find peaks in 2D-array
     def peaks2d(self, X):
         """Detect peaks and valleys in a 2D-array or image.
+        
+        Description
+        -----------
+        Methodology. The idea behind the topology method: Consider the function graph of the function that assigns each pixel its level.
+        Now consider a water level at height 255 that continuously descents to lower levels. At local maxima islands pop up (birth). At saddle points two islands merge; we consider the lower island to be merged to the higher island (death). The so-called persistence diagram (of the 0-th dimensional homology classes, our islands) depicts death- over birth-values of all islands.
+        The persistence of an island is then the difference between the birth- and death-level; the vertical distance of a dot to the grey main diagonal. The figure labels the islands by decreasing persistence.
+        The very first picture shows the locations of births of the islands. This method not only gives the local maxima but also quantifies their "significance" by the above mentioned persistence. One would then filter out all islands with a too low persistence. However, in your example every island (i.e., every local maximum) is a peak you look for.
 
         Parameters
         ----------
@@ -212,8 +218,8 @@ class findpeaks():
         >>>
         >>> # Image example
         >>> from findpeaks import findpeaks
-        >>> fp = findpeaks(denoise=30, resize=(300,300))
         >>> X = fp.import_example('2dpeaks_image')
+        >>> fp = findpeaks(denoise=30, resize=(300,300))
         >>> results = fp.fit(X)
         >>> fp.plot()
         >>>
@@ -341,15 +347,20 @@ class findpeaks():
         fig_axis : tuple containing (fig, ax)
 
         """
-        figsize = figsize if figsize is not None else self.args['figsize']
-
         if not hasattr(self, 'results'):
             print('[findpeaks] Nothing to plot.')
-            return
-        elif self.args['method']=='peaks1d':
+            return None
+
+        figsize = figsize if figsize is not None else self.args['figsize']
+
+        if self.args['method']=='peaks1d':
             fig_axis = self.plot1d(figsize=figsize)
         elif self.args['method']=='peaks2d':
             fig_axis = self.plot2d(figsize=figsize)
+        else:
+            print('[findpeaks] Nothing to plot for %s' %(self.args['method']))
+            return None
+
         # Return
         return fig_axis
 
@@ -632,8 +643,10 @@ def _import_example(data='2dpeaks', url=None, sep=';', verbose=3):
     # Import local dataset
     if verbose>=3: print('[findpeaks] >Import [%s]' %(PATH_TO_DATA))
     if data=='2dpeaks_image':
+        cv2 = compute._import_cv2()
         X = cv2.imread(PATH_TO_DATA)
     else:
         X = pd.read_csv(PATH_TO_DATA, sep=sep).values
     # Return
     return X
+
